if exists("did_load_filetypes")
  finish
endif
let did_load_filetypes = 1
let s:cpo_save = &cpo
set cpo&vim

augroup filetypedetect
if exists("*fnameescape")
au BufNewFile,BufRead ?\+.orig,?\+.bak,?\+.old,?\+.new,?\+.dpkg-dist,?\+.dpkg-old,?\+.dpkg-new,?\+.dpkg-bak,?\+.rpmsave,?\+.rpmnew,?\+.pacsave,?\+.pacnew
	\ exe "doau filetypedetect BufRead " . fnameescape(expand("<afile>:r"))
au BufNewFile,BufRead *~
	\ let s:name = expand("<afile>") |
	\ let s:short = substitute(s:name, '\~$', '', '') |
	\ if s:name != s:short && s:short != "" |
	\   exe "doau filetypedetect BufRead " . fnameescape(s:short) |
	\ endif |
	\ unlet! s:name s:short
au BufNewFile,BufRead ?\+.in
	\ if expand("<afile>:t") != "configure.in" |
	\   exe "doau filetypedetect BufRead " . fnameescape(expand("<afile>:r")) |
	\ endif
elseif &verbose > 0
  echomsg "Warning: some filetypes will not be recognized because this version of Vim does not have fnameescape()"
endif
if !exists("g:ft_ignore_pat")
  let g:ft_ignore_pat = '\.\(Z\|gz\|bz2\|zip\|tgz\)$'
endif
func! s:StarSetf(ft)
  if expand("<amatch>") !~ g:ft_ignore_pat
    exe 'setf ' . a:ft
  endif
endfunc
au BufNewFile,BufRead $VIMRUNTIME/doc/*.txt	setf help
au BufNewFile,BufRead *.inp			call s:Check_inp()

func! s:Check_inp()
  if getline(1) =~ '^\*'
    setf abaqus
  else
    let n = 1
    if line("$") > 500
      let nmax = 500
    else
      let nmax = line("$")
    endif
    while n <= nmax
      if getline(n) =~? "^header surface data"
	setf trasys
	break
      endif
      let n = n + 1
    endwhile
  endif
endfunc
au BufNewFile,BufRead *.aap			setf aap
au BufNewFile,BufRead */etc/a2ps.cfg,*/etc/a2ps/*.cfg,a2psrc,.a2psrc setf a2ps
au BufNewFile,BufRead *.abap			setf abap

au BufNewFile,BufRead *.abc			setf abc

au BufNewFile,BufRead *.abl			setf abel

au BufNewFile,BufRead *.wrm			setf acedb

au BufNewFile,BufRead *.adb,*.ads,*.ada		setf ada
if has("vms")
  au BufNewFile,BufRead *.gpr,*.ada_m,*.adc	setf ada
else
  au BufNewFile,BufRead *.gpr			setf ada
endif

au BufNewFile,BufRead *.tdf			setf ahdl

au BufNewFile,BufRead *.run			setf ampl

au BufNewFile,BufRead build.xml			setf ant

au BufNewFile,BufRead *.ino,*.pde		setf arduino

au BufNewFile,BufRead proftpd.conf*		call s:StarSetf('apachestyle')

au BufNewFile,BufRead .htaccess,*/etc/httpd/*.conf		setf apache

au BufNewFile,BufRead *.a65			setf a65

au BufNewFile,BufRead *.scpt			setf applescript

au BufNewFile,BufRead *.am
	\ if expand("<afile>") !~? 'Makefile.am\>' | setf elf | endif

au BufNewFile,BufRead .asoundrc,*/usr/share/alsa/alsa.conf,*/etc/asound.conf setf alsaconf

au BufNewFile,BufRead *.aml			setf aml

au BufNewFile,BufRead apt.conf		       setf aptconf
au BufNewFile,BufRead */.aptitude/config       setf aptconf
au BufNewFile,BufRead */etc/apt/apt.conf.d/{[-_[:alnum:]]\+,[-_.[:alnum:]]\+.conf} setf aptconf

au BufNewFile,BufRead .arch-inventory,=tagging-method	setf arch

au BufNewFile,BufRead *.art			setf art

au BufNewFile,BufRead *.asciidoc,*.adoc		setf asciidoc

au BufNewFile,BufRead *.asn,*.asn1		setf asn

au BufNewFile,BufRead *.asa
	\ if exists("g:filetype_asa") |
	\   exe "setf " . g:filetype_asa |
	\ else |
	\   setf aspvbs |
	\ endif

au BufNewFile,BufRead *.asp
	\ if exists("g:filetype_asp") |
	\   exe "setf " . g:filetype_asp |
	\ elseif getline(1) . getline(2) . getline(3) =~? "perlscript" |
	\   setf aspperl |
	\ else |
	\   setf aspvbs |
	\ endif

au BufNewFile,BufRead */boot/grub/menu.lst,*/boot/grub/grub.conf,*/etc/grub.conf setf grub

au BufNewFile,BufRead *.asm,*.[sS],*.[aA],*.mac,*.lst	call s:FTasm()

func! s:FTasm()
  " make sure b:asmsyntax exists
  if !exists("b:asmsyntax")
    let b:asmsyntax = ""
  endif

  if b:asmsyntax == ""
    call s:FTasmsyntax()
  endif

  " if b:asmsyntax still isn't set, default to asmsyntax or GNU
  if b:asmsyntax == ""
    if exists("g:asmsyntax")
      let b:asmsyntax = g:asmsyntax
    else
      let b:asmsyntax = "asm"
    endif
  endif

  exe "setf " . fnameescape(b:asmsyntax)
endfunc

func! s:FTasmsyntax()
  " see if file contains any asmsyntax=foo overrides. If so, change
  " b:asmsyntax appropriately
  let head = " ".getline(1)." ".getline(2)." ".getline(3)." ".getline(4).
	\" ".getline(5)." "
  let match = matchstr(head, '\sasmsyntax=\zs[a-zA-Z0-9]\+\ze\s')
  if match != ''
    let b:asmsyntax = match
  elseif ((head =~? '\.title') || (head =~? '\.ident') || (head =~? '\.macro') || (head =~? '\.subtitle') || (head =~? '\.library'))
    let b:asmsyntax = "vmasm"
  endif
endfunc

au BufNewFile,BufRead *.mar			setf vmasm

au BufNewFile,BufRead *.atl,*.as		setf atlas

au BufNewFile,BufRead *.au3			setf autoit

au BufNewFile,BufRead *.ahk			setf autohotkey

au BufNewFile,BufRead [mM]akefile.am,GNUmakefile.am	setf automake

au BufNewFile,BufRead *.at			setf m4

au BufNewFile,BufRead *.ave			setf ave

au BufNewFile,BufRead *.awk			setf awk

au BufNewFile,BufRead *.mch,*.ref,*.imp		setf b

au BufNewFile,BufRead *.bas			call s:FTVB("basic")

func! s:FTVB(alt)
  if getline(1).getline(2).getline(3).getline(4).getline(5) =~? 'VB_Name\|Begin VB\.\(Form\|MDIForm\|UserControl\)'
    setf vb
  else
    exe "setf " . a:alt
  endif
endfunc

au BufNewFile,BufRead *.vb,*.vbs,*.dsm,*.ctl	setf vb

au BufNewFile,BufRead *.iba,*.ibi		setf ibasic

au BufNewFile,BufRead *.fb,*.bi			setf freebasic

au BufNewFile,BufRead *.bat,*.sys		setf dosbatch
au BufNewFile,BufRead *.cmd
	\ if getline(1) =~ '^/\*' | setf rexx | else | setf dosbatch | endif

au BufNewFile,BufRead *.btm			call s:FTbtm()
func! s:FTbtm()
  if exists("g:dosbatch_syntax_for_btm") && g:dosbatch_syntax_for_btm
    setf dosbatch
  else
    setf btm
  endif
endfunc

au BufNewFile,BufRead *.bc			setf bc

au BufNewFile,BufRead *.bdf			setf bdf

au BufNewFile,BufRead *.bib			setf bib

au BufNewFile,BufRead *.bst			setf bst

au BufNewFile,BufRead named*.conf,rndc*.conf	setf named

au BufNewFile,BufRead named.root		setf bindzone
au BufNewFile,BufRead *.db			call s:BindzoneCheck('')

func! s:BindzoneCheck(default)
  if getline(1).getline(2).getline(3).getline(4) =~ '^; <<>> DiG [0-9.]\+ <<>>\|BIND.*named\|$ORIGIN\|$TTL\|IN\s\+SOA'
    setf bindzone
  elseif a:default != ''
    exe 'setf ' . a:default
  endif
endfunc

au BufNewFile,BufRead *.bl			setf blank

au BufNewFile,BufRead */etc/blkid.tab,*/etc/blkid.tab.old   setf xml

autocmd BufRead,BufNewFile *.bzl,WORKSPACE 	setf bzl
if has("fname_case")
  " There is another check for BUILD further below.
  autocmd BufRead,BufNewFile BUILD		setf bzl
endif

au BufNewFile,BufRead *.c			call s:FTlpc()

func! s:FTlpc()
  if exists("g:lpc_syntax_for_c")
    let lnum = 1
    while lnum <= 12
      if getline(lnum) =~# '^\(//\|inherit\|private\|protected\|nosave\|string\|object\|mapping\|mixed\)'
	setf lpc
	return
      endif
      let lnum = lnum + 1
    endwhile
  endif
  setf c
endfunc

au BufNewFile,BufRead calendar			setf calendar

au BufNewFile,BufRead *.cs			setf cs

au BufNewFile,BufRead *.csdl			setf csdl

au BufNewFile,BufRead *.cabal			setf cabal

au BufNewFile,BufRead *.toc			setf cdrtoc

au BufNewFile,BufRead */etc/cdrdao.conf,*/etc/defaults/cdrdao,*/etc/default/cdrdao,.cdrdao	setf cdrdaoconf

au BufNewFile,BufRead cfengine.conf		setf cfengine

au BufRead,BufNewFile *.chai			setf chaiscript

au BufNewFile,BufRead *.cdl			setf cdl

au BufNewFile,BufRead *.recipe			setf conaryrecipe

au BufNewFile,BufRead *.crm			setf crm

au BufNewFile,BufRead *.cyn			setf cynpp

au BufNewFile,BufRead *.cc
	\ if exists("cynlib_syntax_for_cc")|setf cynlib|else|setf cpp|endif
au BufNewFile,BufRead *.cpp
	\ if exists("cynlib_syntax_for_cpp")|setf cynlib|else|setf cpp|endif

au BufNewFile,BufRead *.cxx,*.c++,*.hh,*.hxx,*.hpp,*.ipp,*.moc,*.tcc,*.inl setf cpp
if has("fname_case")
  au BufNewFile,BufRead *.C,*.H setf cpp
endif

au BufNewFile,BufRead *.h			call s:FTheader()

func! s:FTheader()
  if match(getline(1, min([line("$"), 200])), '^@\(interface\|end\|class\)') > -1
    if exists("g:c_syntax_for_h")
      setf objc
    else
      setf objcpp
    endif
  elseif exists("g:c_syntax_for_h")
    setf c
  elseif exists("g:ch_syntax_for_h")
    setf ch
  else
    setf cpp
  endif
endfunc

au BufNewFile,BufRead *.chf			setf ch

au BufNewFile,BufRead *.tlh			setf cpp

au BufNewFile,BufRead *.css			setf css

au BufNewFile,BufRead *.con			setf cterm

au BufNewFile,BufRead changelog.Debian,changelog.dch,NEWS.Debian,NEWS.dch
					\	setf debchangelog

au BufNewFile,BufRead [cC]hange[lL]og
	\  if getline(1) =~ '; urgency='
	\|   setf debchangelog
	\| else
	\|   setf changelog
	\| endif

au BufNewFile,BufRead NEWS
	\  if getline(1) =~ '; urgency='
	\|   setf debchangelog
	\| endif

au BufNewFile,BufRead *..ch			setf chill

au BufNewFile,BufRead *.ch			call s:FTchange()

func! s:FTchange()
  let lnum = 1
  while lnum <= 10
    if getline(lnum)[0] == '@'
      setf change
      return
    endif
    if lnum == 1 && (getline(1)[0] == '#' || getline(1)[0] == '!')
      setf ch
      return
    endif
    if getline(lnum) =~ "MODULE"
      setf chill
      return
    endif
    if getline(lnum) =~ 'main\s*(\|#\s*include\|//'
      setf ch
      return
    endif
    let lnum = lnum + 1
  endwhile
  setf chill
endfunc

au BufNewFile,BufRead *.chopro,*.crd,*.cho,*.crdpro,*.chordpro	setf chordpro

au BufNewFile,BufRead *.dcl,*.icl		setf clean

au BufNewFile,BufRead *.eni			setf cl

au BufNewFile,BufRead *.ent			call s:FTent()

func! s:FTent()
  " This function checks for valid cl syntax in the first five lines.
  " Look for either an opening comment, '#', or a block start, '{".
  " If not found, assume SGML.
  let lnum = 1
  while lnum < 6
    let line = getline(lnum)
    if line =~ '^\s*[#{]'
      setf cl
      return
    elseif line !~ '^\s*$'
      " Not a blank line, not a comment, and not a block start,
      " so doesn't look like valid cl code.
      break
    endif
    let lnum = lnum + 1
  endw
  setf dtd
endfunc

au BufNewFile,BufRead *.prg
	\ if exists("g:filetype_prg") |
	\   exe "setf " . g:filetype_prg |
	\ else |
	\   setf clipper |
	\ endif

au BufNewFile,BufRead *.clj,*.cljs,*.cljx,*.cljc		setf clojure

au BufNewFile,BufRead CMakeLists.txt,*.cmake,*.cmake.in		setf cmake

au BufNewFile,BufRead */.cmus/{autosave,rc,command-history,*.theme} setf cmusrc
au BufNewFile,BufRead */cmus/{rc,*.theme}			setf cmusrc

au BufNewFile,BufRead *.cbl,*.cob,*.lib	setf cobol
au BufNewFile,BufRead *.cpy
	\ if getline(1) =~ '^##' |
	\   setf python |
	\ else |
	\   setf cobol |
	\ endif

au BufNewFile,BufRead *.atg			setf coco

au BufNewFile,BufRead *.cfm,*.cfi,*.cfc		setf cf

au BufNewFile,BufRead configure.in,configure.ac setf config

au BufNewFile,BufRead *.cu			setf cuda

au BufNewFile,BufRead Dockerfile,*.Dockerfile	setf dockerfile

au BufNewFile,BufRead *.dcd			setf dcd

au BufNewFile,BufRead *enlightenment/*.cfg	setf c

au BufNewFile,BufRead *Eterm/*.cfg		setf eterm

au BufNewFile,BufRead *.eu,*.ew,*.ex,*.exu,*.exw  call s:EuphoriaCheck()
if has("fname_case")
   au BufNewFile,BufRead *.EU,*.EW,*.EX,*.EXU,*.EXW  call s:EuphoriaCheck()
endif

func! s:EuphoriaCheck()
  if exists('g:filetype_euphoria')
    exe 'setf ' . g:filetype_euphoria
  else
    setf euphoria3
  endif
endfunc

au BufNewFile,BufRead lynx.cfg			setf lynx

au BufNewFile,BufRead *baseq[2-3]/*.cfg,*id1/*.cfg	setf quake
au BufNewFile,BufRead *quake[1-3]/*.cfg			setf quake

au BufNewFile,BufRead *.qc			setf c

au BufNewFile,BufRead *.cfg			setf cfg

au BufNewFile,BufRead *.feature			setf cucumber

au BufNewFile,BufRead *.csp,*.fdr		setf csp

au BufNewFile,BufRead *.pld			setf cupl
au BufNewFile,BufRead *.si			setf cuplsim

au BufNewFile,BufRead */debian/control		setf debcontrol
au BufNewFile,BufRead control
	\  if getline(1) =~ '^Source:'
	\|   setf debcontrol
	\| endif

au BufNewFile,BufRead */etc/apt/sources.list		setf debsources
au BufNewFile,BufRead */etc/apt/sources.list.d/*.list	setf debsources

au BufNewFile,BufRead denyhosts.conf		setf denyhosts

au BufNewFile,BufRead */etc/dnsmasq.conf	setf dnsmasq

au BufNewFile,BufRead *.desc			setf desc

au BufNewFile,BufRead *.d			call s:DtraceCheck()

func! s:DtraceCheck()
  let lines = getline(1, min([line("$"), 100]))
  if match(lines, '^module\>\|^import\>') > -1
    " D files often start with a module and/or import statement.
    setf d
  elseif match(lines, '^#!\S\+dtrace\|#pragma\s\+D\s\+option\|:\S\{-}:\S\{-}:') > -1
    setf dtrace
  else
    setf d
  endif
endfunc

au BufNewFile,BufRead *.desktop,.directory	setf desktop

au BufNewFile,BufRead dict.conf,.dictrc		setf dictconf

au BufNewFile,BufRead dictd.conf		setf dictdconf

au BufNewFile,BufRead *.diff,*.rej		setf diff
au BufNewFile,BufRead *.patch
	\ if getline(1) =~ '^From [0-9a-f]\{40\} Mon Sep 17 00:00:00 2001$' |
	\   setf gitsendemail |
	\ else |
	\   setf diff |
	\ endif

au BufNewFile,BufRead .dir_colors,.dircolors,*/etc/DIR_COLORS	setf dircolors

au BufNewFile,BufRead *.rul
	\ if getline(1).getline(2).getline(3).getline(4).getline(5).getline(6) =~? 'InstallShield' |
	\   setf ishd |
	\ else |
	\   setf diva |
	\ endif

au BufNewFile,BufRead *.com			call s:BindzoneCheck('dcl')

au BufNewFile,BufRead *.dot			setf dot

au BufNewFile,BufRead *.lid			setf dylanlid

au BufNewFile,BufRead *.intr			setf dylanintr

au BufNewFile,BufRead *.dylan			setf dylan

au BufNewFile,BufRead *.def			setf def

au BufNewFile,BufRead *.drac,*.drc,*lvs,*lpe	setf dracula

au BufNewFile,BufRead *.ds			setf datascript

au BufNewFile,BufRead *.dsl			setf dsl

au BufNewFile,BufRead *.dtd			setf dtd

au BufNewFile,BufRead *.dts,*.dtsi		setf dts

au BufNewFile,BufRead *.ed\(f\|if\|o\)		setf edif
au BufNewFile,BufRead *.edn
	\ if getline(1) =~ '^\s*(\s*edif\>' |
	\   setf edif |
	\ else |
	\   setf clojure |
	\ endif

au BufNewFile,BufRead .editorconfig		setf dosini

au BufNewFile,BufRead *.ecd			setf ecd

au BufNewFile,BufRead *.e,*.E			call s:FTe()

au BufNewFile,BufRead */etc/elinks.conf,*/.elinks/elinks.conf	setf elinks

func! s:FTe()
  if exists('g:filetype_euphoria')
    exe 'setf ' . g:filetype_euphoria
  else
    let n = 1
    while n < 100 && n < line("$")
      if getline(n) =~ "^\\s*\\(<'\\|'>\\)\\s*$"
	setf specman
	return
      endif
      let n = n + 1
    endwhile
    setf eiffel
  endif
endfunc

au BufNewFile,BufRead *.erl,*.hrl,*.yaws	setf erlang

au BufNewFile,BufRead filter-rules		setf elmfilt

au BufNewFile,BufRead *esmtprc			setf esmtprc

au BufNewFile,BufRead *.ec,*.EC			setf esqlc

au BufNewFile,BufRead *.strl			setf esterel

au BufNewFile,BufRead *.csc			setf csc

au BufNewFile,BufRead exim.conf			setf exim

au BufNewFile,BufRead *.exp			setf expect

au BufNewFile,BufRead exports			setf exports

au BufNewFile,BufRead *.fal			setf falcon

au BufNewFile,BufRead *.fan,*.fwt		setf fan

au BufNewFile,BufRead *.factor			setf factor

au BufNewFile,BufRead .fetchmailrc		setf fetchmail


au BufNewFile,BufRead *.fex,*.focexec		setf focexec

au BufNewFile,BufRead auto.master		setf conf
au BufNewFile,BufRead *.mas,*.master		setf master

au BufNewFile,BufRead *.fs,*.ft			setf forth

au BufNewFile,BufRead *.frt			setf reva

if has("fname_case")
  au BufNewFile,BufRead *.F,*.FOR,*.FPP,*.FTN,*.F77,*.F90,*.F95,*.F03,*.F08	 setf fortran
endif
au BufNewFile,BufRead   *.f,*.for,*.fortran,*.fpp,*.ftn,*.f77,*.f90,*.f95,*.f03,*.f08  setf fortran

au BufNewFile,BufRead *.fsl			setf framescript

au BufNewFile,BufRead fstab,mtab		setf fstab

au BufNewFile,BufRead .gdbinit			setf gdb

au BufNewFile,BufRead *.mo,*.gdmo		setf gdmo

au BufNewFile,BufRead *.ged,lltxxxxx.txt	setf gedcom

au BufNewFile,BufRead COMMIT_EDITMSG,MERGE_MSG,TAG_EDITMSG setf gitcommit
au BufNewFile,BufRead *.git/config,.gitconfig,.gitmodules setf gitconfig
au BufNewFile,BufRead *.git/modules/*/config	setf gitconfig
au BufNewFile,BufRead */.config/git/config	setf gitconfig
if !empty($XDG_CONFIG_HOME)
  au BufNewFile,BufRead $XDG_CONFIG_HOME/git/config	setf gitconfig
endif
au BufNewFile,BufRead git-rebase-todo		setf gitrebase
au BufRead,BufNewFile .gitsendemail.msg.??????	setf gitsendemail
au BufNewFile,BufRead .msg.[0-9]*
      \ if getline(1) =~ '^From.*# This line is ignored.$' |
      \   setf gitsendemail |
      \ endif
au BufNewFile,BufRead *.git/*
      \ if getline(1) =~ '^\x\{40\}\>\|^ref: ' |
      \   setf git |
      \ endif

au BufNewFile,BufRead gkrellmrc,gkrellmrc_?	setf gkrellmrc

au BufNewFile,BufRead *.gp,.gprc		setf gp

au BufNewFile,BufRead */.gnupg/options		setf gpg
au BufNewFile,BufRead */.gnupg/gpg.conf		setf gpg
au BufNewFile,BufRead */usr/*/gnupg/options.skel setf gpg
if !empty($GNUPGHOME)
  au BufNewFile,BufRead $GNUPGHOME/options	setf gpg
  au BufNewFile,BufRead $GNUPGHOME/gpg.conf	setf gpg
endif

au BufNewFile,BufRead gnashrc,.gnashrc,gnashpluginrc,.gnashpluginrc setf gnash

au BufNewFile,BufRead gitolite.conf		setf gitolite
au BufNewFile,BufRead */gitolite-admin/conf/*	call s:StarSetf('gitolite')
au BufNewFile,BufRead {,.}gitolite.rc,example.gitolite.rc	setf perl

au BufNewFile,BufRead *.gpi			setf gnuplot

au BufNewFile,BufRead *.go			setf go

au BufNewFile,BufRead *.gs			setf grads

au BufNewFile,BufRead *.gretl			setf gretl

au BufNewFile,BufRead *.gradle,*.groovy		setf groovy

au BufNewFile,BufRead *.gsp			setf gsp

au BufNewFile,BufRead */etc/group,*/etc/group-,*/etc/group.edit,*/etc/gshadow,*/etc/gshadow-,*/etc/gshadow.edit,*/var/backups/group.bak,*/var/backups/gshadow.bak  setf group

au BufNewFile,BufRead .gtkrc,gtkrc		setf gtkrc

au BufNewFile,BufRead *.haml			setf haml

au BufNewFile,BufRead *.hsc,*.hsm		setf hamster

au BufNewFile,BufRead *.hs,*.hs-boot		setf haskell
au BufNewFile,BufRead *.lhs			setf lhaskell
au BufNewFile,BufRead *.chs			setf chaskell

au BufNewFile,BufRead *.ht			setf haste
au BufNewFile,BufRead *.htpp			setf hastepreproc

au BufNewFile,BufRead *.vc,*.ev,*.sum,*.errsum	setf hercules

au BufNewFile,BufRead *.hex,*.h32		setf hex

au BufNewFile,BufRead *.t.html			setf tilde

au BufNewFile,BufRead *.html,*.htm,*.shtml,*.stm  call s:FThtml()

func! s:FThtml()
  let n = 1
  while n < 10 && n < line("$")
    if getline(n) =~ '\<DTD\s\+XHTML\s'
      setf xhtml
      return
    endif
    if getline(n) =~ '{%\s*\(extends\|block\|load\)\>\|{#\s\+'
      setf htmldjango
      return
    endif
    let n = n + 1
  endwhile
  setf html
endfunc

au BufNewFile,BufRead *.erb,*.rhtml		setf eruby

au BufNewFile,BufRead *.html.m4			setf htmlm4

au BufNewFile,BufRead *.tmpl			setf htmlcheetah

au BufNewFile,BufRead */etc/host.conf		setf hostconf

au BufNewFile,BufRead */etc/hosts.allow,*/etc/hosts.deny  setf hostsaccess

au BufNewFile,BufRead *.hb			setf hb

au BufNewFile,BufRead *.htt,*.htb		setf httest

au BufNewFile,BufRead *.icn			setf icon

au BufNewFile,BufRead *.idl			call s:FTidl()

func! s:FTidl()
  let n = 1
  while n < 50 && n < line("$")
    if getline(n) =~ '^\s*import\s\+"\(unknwn\|objidl\)\.idl"'
      setf msidl
      return
    endif
    let n = n + 1
  endwhile
  setf idl
endfunc

au BufNewFile,BufRead *.odl,*.mof		setf msidl

au BufNewFile,BufRead */.icewm/menu		setf icemenu

au BufNewFile,BufRead .indent.pro		setf indent
au BufNewFile,BufRead indent.pro		call s:ProtoCheck('indent')

au BufNewFile,BufRead *.pro			call s:ProtoCheck('idlang')

func! s:ProtoCheck(default)
  " Cproto files have a comment in the first line and a function prototype in
  " the second line, it always ends in ";".  Indent files may also have
  " comments, thus we can't match comments to see the difference.
  " IDL files can have a single ';' in the second line, require at least one
  " chacter before the ';'.
  if getline(2) =~ '.;$'
    setf cpp
  else
    exe 'setf ' . a:default
  endif
endfunc


au BufNewFile,BufRead indentrc			setf indent

au BufNewFile,BufRead *.inf,*.INF		setf inform

au BufNewFile,BufRead */etc/initng/*/*.i,*.ii	setf initng

au BufRead,BufNewFile upstream.dat\c,upstream.*.dat\c,*.upstream.dat\c 	setf upstreamdat
au BufRead,BufNewFile fdrupstream.log,upstream.log\c,upstream.*.log\c,*.upstream.log\c,UPSTREAM-*.log\c 	setf upstreamlog
au BufRead,BufNewFile upstreaminstall.log\c,upstreaminstall.*.log\c,*.upstreaminstall.log\c setf upstreaminstalllog
au BufRead,BufNewFile usserver.log\c,usserver.*.log\c,*.usserver.log\c 	setf usserverlog
au BufRead,BufNewFile usw2kagt.log\c,usw2kagt.*.log\c,*.usw2kagt.log\c 	setf usw2kagtlog

au BufNewFile,BufRead ipf.conf,ipf6.conf,ipf.rules	setf ipfilter

au BufNewFile,BufRead *.4gl,*.4gh,*.m4gl	setf fgl

au BufNewFile,BufRead *.ini			setf dosini

au BufNewFile,BufRead inittab			setf inittab

au BufNewFile,BufRead *.iss			setf iss

au BufNewFile,BufRead *.ijs			setf j

au BufNewFile,BufRead *.jal,*.JAL		setf jal

au BufNewFile,BufRead *.jpl,*.jpr		setf jam

au BufNewFile,BufRead *.java,*.jav		setf java

au BufNewFile,BufRead *.jj,*.jjt		setf javacc

au BufNewFile,BufRead *.js,*.javascript,*.es,*.jsx,*.mjs   setf javascript

au BufNewFile,BufRead *.jsp			setf jsp

au BufNewFile,BufRead *.properties,*.properties_??,*.properties_??_??	setf jproperties
au BufNewFile,BufRead *.properties_??_??_*	call s:StarSetf('jproperties')

au BufNewFile,BufRead *.clp			setf jess

au BufNewFile,BufRead *.jgr			setf jgraph

au BufNewFile,BufRead *.jov,*.j73,*.jovial	setf jovial

au BufNewFile,BufRead *.json,*.jsonp,*.webmanifest	setf json

au BufNewFile,BufRead *.kix			setf kix

au BufNewFile,BufRead *.k			setf kwt

au BufNewFile,BufRead *.kv			setf kivy

au BufNewFile,BufRead *.ks			setf kscript

au BufNewFile,BufRead Kconfig,Kconfig.debug	setf kconfig

au BufNewFile,BufRead *.ace,*.ACE		setf lace

au BufNewFile,BufRead *.latte,*.lte		setf latte

au BufNewFile,BufRead */etc/limits,*/etc/*limits.conf,*/etc/*limits.d/*.conf	setf limits

au BufNewFile,BufRead *.sig			setf lprolog

au BufNewFile,BufRead *.ldif			setf ldif

au BufNewFile,BufRead *.ld			setf ld

au BufNewFile,BufRead *.less			setf less

au BufNewFile,BufRead *.lex,*.l,*.lxx,*.l++	setf lex

au BufNewFile,BufRead */etc/libao.conf,*/.libao	setf libao

au BufNewFile,BufRead */etc/sensors.conf,*/etc/sensors3.conf	setf sensors

au BufNewFile,BufRead lftp.conf,.lftprc,*lftp/rc	setf lftp

au BufNewFile,BufRead *.ll			setf lifelines

au BufNewFile,BufRead lilo.conf			setf lilo

if has("fname_case")
  au BufNewFile,BufRead *.lsp,*.lisp,*.el,*.cl,*.jl,*.L,.emacs,.sawfishrc setf lisp
else
  au BufNewFile,BufRead *.lsp,*.lisp,*.el,*.cl,*.jl,.emacs,.sawfishrc setf lisp
endif

au BufNewFile,BufRead sbclrc,.sbclrc		setf lisp

au BufNewFile,BufRead *.liquid			setf liquid

au BufNewFile,BufRead *.lite,*.lt		setf lite

au BufNewFile,BufRead */LiteStep/*/*.rc		setf litestep

au BufNewFile,BufRead */etc/login.access	setf loginaccess

au BufNewFile,BufRead */etc/login.defs		setf logindefs

au BufNewFile,BufRead *.lgt			setf logtalk

au BufNewFile,BufRead *.lot,*.lotos		setf lotos

au BufNewFile,BufRead *.lou,*.lout		setf lout

au BufNewFile,BufRead *.lua			setf lua

au BufNewFile,BufRead *.rockspec		setf lua

au BufNewFile,BufRead *.lsl			setf lsl

au BufNewFile,BufRead *.lss			setf lss

au BufNewFile,BufRead *.m4
	\ if expand("<afile>") !~? 'html.m4$\|fvwm2rc' | setf m4 | endif

au BufNewFile,BufRead *.mgp			setf mgp

au BufNewFile,BufRead snd.\d\+,.letter,.letter.\d\+,.followup,.article,.article.\d\+,pico.\d\+,mutt{ng,}-*-\w\+,mutt[[:alnum:]_-]\\\{6\},ae\d\+.txt,/tmp/SLRN[0-9A-Z.]\+,*.eml setf mail

au BufNewFile,BufRead */etc/mail/aliases,*/etc/aliases	setf mailaliases

au BufNewFile,BufRead .mailcap,mailcap		setf mailcap

au BufNewFile,BufRead *[mM]akefile,*.mk,*.mak,*.dsp setf make

au BufNewFile,BufRead *.ist,*.mst		setf ist

au BufNewFile,BufRead *.page			setf mallard

au BufNewFile,BufRead *.man			setf man

au BufNewFile,BufRead */etc/man.conf,man.config	setf manconf

au BufNewFile,BufRead *.mv,*.mpl,*.mws		setf maple

au BufNewFile,BufRead *.map			setf map

au BufNewFile,BufRead *.markdown,*.mdown,*.mkd,*.mkdn,*.mdwn,*.md  setf markdown

au BufNewFile,BufRead *.mason,*.mhtml,*.comp	setf mason

au BufNewFile,BufRead *.m			call s:FTm()

func! s:FTm()
  let n = 1
  let saw_comment = 0 " Whether we've seen a multiline comment leader.
  while n < 100
    let line = getline(n)
    if line =~ '^\s*/\*'
      " /* ... */ is a comment in Objective C and Murphi, so we can't conclude
      " it's either of them yet, but track this as a hint in case we don't see
      " anything more definitive.
      let saw_comment = 1
    endif
    if line =~ '^\s*\(#\s*\(include\|import\)\>\|@import\>\|//\)'
      setf objc
      return
    endif
    if line =~ '^\s*%'
      setf matlab
      return
    endif
    if line =~ '^\s*(\*'
      setf mma
      return
    endif
    if line =~ '^\c\s*\(\(type\|var\)\>\|--\)'
      setf murphi
      return
    endif
    let n = n + 1
  endwhile

  if saw_comment
    " We didn't see anything definitive, but this looks like either Objective C
    " or Murphi based on the comment leader. Assume the former as it is more
    " common.
    setf objc
  elseif exists("g:filetype_m")
    " Use user specified default filetype for .m
    exe "setf " . g:filetype_m
  else
    " Default is matlab
    setf matlab
  endif
endfunc

au BufNewFile,BufRead *.nb			setf mma

au BufNewFile,BufRead *.mel			setf mel

au BufNewFile,BufRead hg-editor-*.txt		setf hgcommit

au BufNewFile,BufRead *.hgrc,*hgrc		setf cfg

au BufNewFile,BufRead */log/{auth,cron,daemon,debug,kern,lpr,mail,messages,news/news,syslog,user}{,.log,.err,.info,.warn,.crit,.notice}{,.[0-9]*,-[0-9]*} setf messages

au BufNewFile,BufRead *.mf			setf mf

au BufNewFile,BufRead *.mp			setf mp

au BufNewFile,BufRead *.mgl			setf mgl

au BufNewFile,BufRead *.mix,*.mixal		setf mix

au BufNewFile,BufRead *.mms			call s:FTmms()

au BufNewFile,BufRead *.mmp			setf mmp

func! s:FTmms()
  let n = 1
  while n < 10
    let line = getline(n)
    if line =~ '^\s*\(%\|//\)' || line =~ '^\*'
      setf mmix
      return
    endif
    if line =~ '^\s*#'
      setf make
      return
    endif
    let n = n + 1
  endwhile
  setf mmix
endfunc


au BufNewFile,BufRead *.mod
	\ if getline(1) =~ '\<module\>' |
	\   setf lprolog |
	\ else |
	\   setf modsim3 |
	\ endif

au BufNewFile,BufRead *.m2,*.DEF,*.MOD,*.mi	setf modula2

au BufNewFile,BufRead *.[mi][3g]		setf modula3

au BufNewFile,BufRead *.isc,*.monk,*.ssc,*.tsc	setf monk

au BufNewFile,BufRead *.moo			setf moo

au BufNewFile,BufRead */etc/modules.conf,*/etc/modules,*/etc/conf.modules setf modconf

au BufNewFile,BufRead mplayer.conf,*/.mplayer/config	setf mplayerconf

au BufNewFile,BufRead *.s19,*.s28,*.s37,*.mot,*.srec	setf srec

au BufNewFile,BufRead mrxvtrc,.mrxvtrc		setf mrxvtrc

au BufNewFile,BufRead *.msql			setf msql

au BufNewFile,BufRead *.mysql			setf mysql

au BufNewFile,BufRead */etc/Muttrc.d/*		call s:StarSetf('muttrc')

au BufNewFile,BufRead *.rc,*.rch		setf rc

au BufRead,BufNewFile *.mu			setf mupad

au BufNewFile,BufRead *.mush			setf mush

au BufNewFile,BufRead Mutt{ng,}rc		setf muttrc

au BufRead,BufNewfile *.n1ql,*.nql		setf n1ql

au BufNewFile,BufRead */etc/nanorc,*.nanorc  	setf nanorc


au BufNewFile,BufRead *.NS[ACGLMNPS]		setf natural

au BufNewFile,BufRead .netrc			setf netrc

au BufNewFile,BufRead *.ninja			setf ninja

au BufNewFile,BufRead *.ncf			setf ncf

au BufNewFile,BufRead *.me
	\ if expand("<afile>") != "read.me" && expand("<afile>") != "click.me" |
	\   setf nroff |
	\ endif
au BufNewFile,BufRead *.tr,*.nr,*.roff,*.tmac,*.mom	setf nroff
au BufNewFile,BufRead *.[1-9]			call s:FTnroff()

func! s:FTnroff()
  if getline(1)[0] . getline(2)[0] . getline(3)[0] . getline(4)[0] . getline(5)[0] =~ '\.'
    setf nroff
    return 1
  endif
  return 0
endfunc

au BufNewFile,BufRead *.mm			call s:FTmm()

func! s:FTmm()
  let n = 1
  while n < 10
    let line = getline(n)
    if line =~ '^\s*\(#\s*\(include\|import\)\>\|@import\>\|/\*\)'
      setf objcpp
      return
    endif
    let n = n + 1
  endwhile
  setf nroff
endfunc

au BufNewFile,BufRead *.nqc			setf nqc

au BufNewFile,BufRead *.nse			setf lua

au BufNewFile,BufRead *.nsi,*.nsh		setf nsis

au BufNewFile,BufRead *.ml,*.mli,*.mll,*.mly,.ocamlinit	setf ocaml

au BufNewFile,BufRead *.occ			setf occam

au BufNewFile,BufRead *.xom,*.xin		setf omnimark

au BufNewFile,BufRead *.or			setf openroad

au BufNewFile,BufRead *.[Oo][Pp][Ll]		setf opl

au BufNewFile,BufRead *.ora			setf ora

au BufNewFile,BufRead pf.conf			setf pf

au BufNewFile,BufRead */etc/pam.conf		setf pamconf

au BufNewFile,BufRead *.papp,*.pxml,*.pxsl	setf papp

au BufNewFile,BufRead */etc/passwd,*/etc/passwd-,*/etc/passwd.edit,*/etc/shadow,*/etc/shadow-,*/etc/shadow.edit,*/var/backups/passwd.bak,*/var/backups/shadow.bak setf passwd

au BufNewFile,BufRead *.pas			setf pascal

au BufNewFile,BufRead *.dpr			setf pascal

au BufNewFile,BufRead *.pdf			setf pdf

if has("fname_case")
  au BufNewFile,BufRead *.pl,*.PL		call s:FTpl()
else
  au BufNewFile,BufRead *.pl			call s:FTpl()
endif
au BufNewFile,BufRead *.plx,*.al,*.psgi		setf perl
au BufNewFile,BufRead *.p6,*.pm6,*.pl6		setf perl6

func! s:FTpl()
  if exists("g:filetype_pl")
    exe "setf " . g:filetype_pl
  else
    " recognize Prolog by specific text in the first non-empty line
    " require a blank after the '%' because Perl uses "%list" and "%translate"
    let l = getline(nextnonblank(1))
    if l =~ '\<prolog\>' || l =~ '^\s*\(%\+\(\s\|$\)\|/\*\)' || l =~ ':-'
      setf prolog
    else
      setf perl
    endif
  endif
endfunc

au BufNewFile,BufRead *.pm
	\ if getline(1) =~ "XPM2" |
	\   setf xpm2 |
	\ elseif getline(1) =~ "XPM" |
	\   setf xpm |
	\ else |
	\   setf perl |
	\ endif

au BufNewFile,BufRead *.pod			setf pod
au BufNewFile,BufRead *.pod6			setf pod6

au BufNewFile,BufRead *.php,*.php\d,*.phtml,*.ctp	setf php

au BufNewFile,BufRead *.pike,*.lpc,*.ulpc,*.pmod setf pike

au BufNewFile,BufRead */etc/pinforc,*/.pinforc	setf pinfo

au BufNewFile,BufRead *.rcp			setf pilrc

au BufNewFile,BufRead .pinerc,pinerc,.pinercex,pinercex		setf pine

au BufNewFile,BufRead *.pli,*.pl1		setf pli

au BufNewFile,BufRead *.plm,*.p36,*.pac		setf plm

au BufNewFile,BufRead *.pls,*.plsql		setf plsql

au BufNewFile,BufRead *.plp			setf plp

au BufNewFile,BufRead *.po,*.pot		setf po

au BufNewFile,BufRead main.cf			setf pfmain

au BufNewFile,BufRead *.ps,*.pfa,*.afm,*.eps,*.epsf,*.epsi,*.ai	  setf postscr

au BufNewFile,BufRead *.ppd			setf ppd

au BufNewFile,BufRead *.pov			setf pov

au BufNewFile,BufRead .povrayrc			setf povini

au BufNewFile,BufRead *.inc			call s:FTinc()

func! s:FTinc()
  if exists("g:filetype_inc")
    exe "setf " . g:filetype_inc
  else
    let lines = getline(1).getline(2).getline(3)
    if lines =~? "perlscript"
      setf aspperl
    elseif lines =~ "<%"
      setf aspvbs
    elseif lines =~ "<?"
      setf php
    else
      call s:FTasmsyntax()
      if exists("b:asmsyntax")
	exe "setf " . fnameescape(b:asmsyntax)
      else
	setf pov
      endif
    endif
  endif
endfunc

au BufNewFile,BufRead *printcap
	\ let b:ptcap_type = "print" | setf ptcap
au BufNewFile,BufRead *termcap
	\ let b:ptcap_type = "term" | setf ptcap

au BufNewFile,BufRead *.g			setf pccts

au BufNewFile,BufRead *.it,*.ih			setf ppwiz

au BufNewFile,BufRead *.obj			setf obj

au BufNewFile,BufRead *.pc			setf proc

au BufNewFile,BufRead *.action			setf privoxy

au BufNewFile,BufRead .procmail,.procmailrc	setf procmail

au BufNewFile,BufRead *.w			call s:FTprogress_cweb()

func! s:FTprogress_cweb()
  if exists("g:filetype_w")
    exe "setf " . g:filetype_w
    return
  endif
  if getline(1) =~ '&ANALYZE' || getline(3) =~ '&GLOBAL-DEFINE'
    setf progress
  else
    setf cweb
  endif
endfunc

au BufNewFile,BufRead *.i			call s:FTprogress_asm()

func! s:FTprogress_asm()
  if exists("g:filetype_i")
    exe "setf " . g:filetype_i
    return
  endif
  " This function checks for an assembly comment the first ten lines.
  " If not found, assume Progress.
  let lnum = 1
  while lnum <= 10 && lnum < line('$')
    let line = getline(lnum)
    if line =~ '^\s*;' || line =~ '^\*'
      call s:FTasm()
      return
    elseif line !~ '^\s*$' || line =~ '^/\*'
      " Not an empty line: Doesn't look like valid assembly code.
      " Or it looks like a Progress /* comment
      break
    endif
    let lnum = lnum + 1
  endw
  setf progress
endfunc

au BufNewFile,BufRead *.p			call s:FTprogress_pascal()

func! s:FTprogress_pascal()
  if exists("g:filetype_p")
    exe "setf " . g:filetype_p
    return
  endif
  " This function checks for valid Pascal syntax in the first ten lines.
  " Look for either an opening comment or a program start.
  " If not found, assume Progress.
  let lnum = 1
  while lnum <= 10 && lnum < line('$')
    let line = getline(lnum)
    if line =~ '^\s*\(program\|unit\|procedure\|function\|const\|type\|var\)\>'
	\ || line =~ '^\s*{' || line =~ '^\s*(\*'
      setf pascal
      return
    elseif line !~ '^\s*$' || line =~ '^/\*'
      " Not an empty line: Doesn't look like valid Pascal code.
      " Or it looks like a Progress /* comment
      break
    endif
    let lnum = lnum + 1
  endw
  setf progress
endfunc


au BufNewFile,BufRead *.psf			setf psf
au BufNewFile,BufRead INDEX,INFO
	\ if getline(1) =~ '^\s*\(distribution\|installed_software\|root\|bundle\|product\)\s*$' |
	\   setf psf |
	\ endif

au BufNewFile,BufRead *.pdb			setf prolog

au BufNewFile,BufRead *.pml			setf promela

au BufNewFile,BufRead *.proto			setf proto

au BufNewFile,BufRead */etc/protocols		setf protocols

au BufNewFile,BufRead *.pyx,*.pxd		setf pyrex

au BufNewFile,BufRead *.py,*.pyw,.pythonstartup,.pythonrc,*.ptl  setf python

au BufNewFile,BufRead *.rad,*.mat		setf radiance

au BufNewFile,BufRead .ratpoisonrc,ratpoisonrc	setf ratpoison

au BufNewFile,BufRead *\,v			setf rcs

au BufNewFile,BufRead .inputrc,inputrc		setf readline

au BufNewFile,BufRead *.reg
	\ if getline(1) =~? '^REGEDIT[0-9]*\s*$\|^Windows Registry Editor Version \d*\.\d*\s*$' | setf registry | endif

au BufNewFile,BufRead *.rib			setf rib

au BufNewFile,BufRead *.rex,*.orx,*.rxo,*.rxj,*.jrexx,*.rexxj,*.rexx,*.testGroup,*.testUnit	setf rexx

if has("fname_case")
  au BufNewFile,BufRead *.s,*.S			setf r
else
  au BufNewFile,BufRead *.s			setf r
endif

if has("fname_case")
  au BufNewFile,BufRead *.rd,*.Rd		setf rhelp
else
  au BufNewFile,BufRead *.rd			setf rhelp
endif

if has("fname_case")
  au BufNewFile,BufRead *.Rnw,*.rnw,*.Snw,*.snw		setf rnoweb
else
  au BufNewFile,BufRead *.rnw,*.snw			setf rnoweb
endif

if has("fname_case")
  au BufNewFile,BufRead *.Rmd,*.rmd,*.Smd,*.smd		setf rmd
else
  au BufNewFile,BufRead *.rmd,*.smd			setf rmd
endif

if has("fname_case")
  au BufNewFile,BufRead *.Rrst,*.rrst,*.Srst,*.srst	setf rrst
else
  au BufNewFile,BufRead *.rrst,*.srst			setf rrst
endif

au BufNewFile,BufRead *.r,*.R			call s:FTr()

func! s:FTr()
  let max = line("$") > 50 ? 50 : line("$")

  for n in range(1, max)
    " Rebol is easy to recognize, check for that first
    if getline(n) =~? '\<REBOL\>'
      setf rebol
      return
    endif
  endfor

  for n in range(1, max)
    " R has # comments
    if getline(n) =~ '^\s*#'
      setf r
      return
    endif
    " Rexx has /* comments */
    if getline(n) =~ '^\s*/\*'
      setf rexx
      return
    endif
  endfor

  " Nothing recognized, use user default or assume Rexx
  if exists("g:filetype_r")
    exe "setf " . g:filetype_r
  else
    " Rexx used to be the default, but R appears to be much more popular.
    setf r
  endif
endfunc

au BufNewFile,BufRead .reminders,*.remind,*.rem		setf remind

au BufNewFile,BufRead resolv.conf		setf resolv

au BufNewFile,BufRead *.rnc			setf rnc

au BufNewFile,BufRead *.rng			setf rng

au BufNewFile,BufRead *.rpl			setf rpl

au BufNewFile,BufRead robots.txt		setf robots

au BufNewFile,BufRead *.x			setf rpcgen

au BufNewFile,BufRead *.rst			setf rst

au BufNewFile,BufRead *.rtf			setf rtf

au BufNewFile,BufRead .irbrc,irbrc		setf ruby

au BufNewFile,BufRead *.rb,*.rbw		setf ruby

au BufNewFile,BufRead *.gemspec			setf ruby

au BufNewFile,BufRead *.rs			setf rust

au BufNewFile,BufRead *.ru			setf ruby

au BufNewFile,BufRead Gemfile			setf ruby

au BufNewFile,BufRead *.builder,*.rxml,*.rjs	setf ruby

au BufNewFile,BufRead [rR]antfile,*.rant,[rR]akefile,*.rake	setf ruby

au BufNewFile,BufRead *.sl			setf slang

au BufNewFile,BufRead smb.conf			setf samba

au BufNewFile,BufRead *.sas			setf sas

au BufNewFile,BufRead *.sass			setf sass

au BufNewFile,BufRead *.sa			setf sather

au BufNewFile,BufRead *.scala			setf scala

au BufNewFile,BufRead *.sbt			setf sbt

au BufNewFile,BufRead *.sci,*.sce		setf scilab

au BufNewFile,BufRead *.scss			setf scss

au BufNewFile,BufRead *.sd			setf sd

au BufNewFile,BufRead *.sdl,*.pr		setf sdl

au BufNewFile,BufRead *.sed			setf sed

au BufNewFile,BufRead *.siv			setf sieve

au BufNewFile,BufRead sendmail.cf		setf sm

au BufNewFile,BufRead *.mc			call s:McSetf()

func! s:McSetf()
  " Rely on the file to start with a comment.
  " MS message text files use ';', Sendmail files use '#' or 'dnl'
  for lnum in range(1, min([line("$"), 20]))
    let line = getline(lnum)
    if line =~ '^\s*\(#\|dnl\)'
      setf m4  " Sendmail .mc file
      return
    elseif line =~ '^\s*;'
      setf msmessages  " MS Message text file
      return
    endif
  endfor
  setf m4  " Default: Sendmail .mc file
endfunc

au BufNewFile,BufRead */etc/services		setf services

au BufNewFile,BufRead */etc/slp.conf		setf slpconf

au BufNewFile,BufRead */etc/slp.reg		setf slpreg

au BufNewFile,BufRead */etc/slp.spi		setf slpspi

au BufNewFile,BufRead */etc/serial.conf		setf setserial

au BufNewFile,BufRead *.sgm,*.sgml
	\ if getline(1).getline(2).getline(3).getline(4).getline(5) =~? 'linuxdoc' |
	\   setf sgmllnx |
	\ elseif getline(1) =~ '<!DOCTYPE.*DocBook' || getline(2) =~ '<!DOCTYPE.*DocBook' |
	\   let b:docbk_type = "sgml" |
	\   let b:docbk_ver = 4 |
	\   setf docbk |
	\ else |
	\   setf sgml |
	\ endif

au BufNewFile,BufRead *.decl,*.dcl,*.dec
	\ if getline(1).getline(2).getline(3) =~? '^<!SGML' |
	\    setf sgmldecl |
	\ endif

au BufNewFile,BufRead catalog			setf catalog
au BufNewFile,BufRead sgml.catalog*		call s:StarSetf('catalog')

au BufNewFile,BufRead .bashrc*,bashrc,bash.bashrc,.bash[_-]profile*,.bash[_-]logout*,.bash[_-]aliases*,*.bash,*/{,.}bash[_-]completion{,.d,.sh}{,/*},*.ebuild,*.eclass,PKGBUILD* call SetFileTypeSH("bash")
au BufNewFile,BufRead .kshrc*,*.ksh call SetFileTypeSH("ksh")
au BufNewFile,BufRead */etc/profile,.profile*,*.sh,*.env call SetFileTypeSH(getline(1))

au BufNewFile,BufRead *.install
	\ if getline(1) =~ '<?php' |
	\   setf php |
	\ else |
	\   call SetFileTypeSH("bash") |
	\ endif

func! SetFileTypeSH(name)
  if expand("<amatch>") =~ g:ft_ignore_pat
    return
  endif
  if a:name =~ '\<csh\>'
    " Some .sh scripts contain #!/bin/csh.
    call SetFileTypeShell("csh")
    return
  elseif a:name =~ '\<tcsh\>'
    " Some .sh scripts contain #!/bin/tcsh.
    call SetFileTypeShell("tcsh")
    return
  elseif a:name =~ '\<zsh\>'
    " Some .sh scripts contain #!/bin/zsh.
    call SetFileTypeShell("zsh")
    return
  elseif a:name =~ '\<ksh\>'
    let b:is_kornshell = 1
    if exists("b:is_bash")
      unlet b:is_bash
    endif
    if exists("b:is_sh")
      unlet b:is_sh
    endif
  elseif exists("g:bash_is_sh") || a:name =~ '\<bash\>' || a:name =~ '\<bash2\>'
    let b:is_bash = 1
    if exists("b:is_kornshell")
      unlet b:is_kornshell
    endif
    if exists("b:is_sh")
      unlet b:is_sh
    endif
  elseif a:name =~ '\<sh\>'
    let b:is_sh = 1
    if exists("b:is_kornshell")
      unlet b:is_kornshell
    endif
    if exists("b:is_bash")
      unlet b:is_bash
    endif
  endif
  call SetFileTypeShell("sh")
endfunc

func! SetFileTypeShell(name)
  if expand("<amatch>") =~ g:ft_ignore_pat
    return
  endif
  let l = 2
  while l < 20 && l < line("$") && getline(l) =~ '^\s*\(#\|$\)'
    " Skip empty and comment lines.
    let l = l + 1
  endwhile
  if l < line("$") && getline(l) =~ '\s*exec\s' && getline(l - 1) =~ '^\s*#.*\\$'
    " Found an "exec" line after a comment with continuation
    let n = substitute(getline(l),'\s*exec\s\+\([^ ]*/\)\=', '', '')
    if n =~ '\<tclsh\|\<wish'
      setf tcl
      return
    endif
  endif
  exe "setf " . a:name
endfunc

au BufNewFile,BufRead .tcshrc*,*.tcsh,tcsh.tcshrc,tcsh.login	call SetFileTypeShell("tcsh")

au BufNewFile,BufRead .login*,.cshrc*,csh.cshrc,csh.login,csh.logout,*.csh,.alias  call s:CSH()

func! s:CSH()
  if exists("g:filetype_csh")
    call SetFileTypeShell(g:filetype_csh)
  elseif &shell =~ "tcsh"
    call SetFileTypeShell("tcsh")
  else
    call SetFileTypeShell("csh")
  endif
endfunc

au BufNewFile,BufRead .zprofile,*/etc/zprofile,.zfbfmarks  setf zsh
au BufNewFile,BufRead .zsh*,.zlog*,.zcompdump*  call s:StarSetf('zsh')
au BufNewFile,BufRead *.zsh			setf zsh

au BufNewFile,BufRead *.scm,*.ss,*.rkt		setf scheme

au BufNewFile,BufRead .screenrc,screenrc	setf screen

au BufNewFile,BufRead *.sim			setf simula

au BufNewFile,BufRead *.sin,*.s85		setf sinda

au BufNewFile,BufRead *.sst,*.ssm,*.ssi,*.-sst,*._sst setf sisu
au BufNewFile,BufRead *.sst.meta,*.-sst.meta,*._sst.meta setf sisu

au BufNewFile,BufRead *.il,*.ils,*.cdf		setf skill

au BufNewFile,BufRead .slrnrc			setf slrnrc
au BufNewFile,BufRead *.score			setf slrnsc

au BufNewFile,BufRead *.st			setf st
au BufNewFile,BufRead *.cls
	\ if getline(1) =~ '^%' |
	\  setf tex |
	\ elseif getline(1)[0] == '#' && getline(1) =~ 'rexx' |
	\  setf rexx |
	\ else |
	\  setf st |
	\ endif

au BufNewFile,BufRead *.tpl			setf smarty

au BufNewFile,BufRead *.smil
	\ if getline(1) =~ '<?\s*xml.*?>' |
	\   setf xml |
	\ else |
	\   setf smil |
	\ endif

au BufNewFile,BufRead *.smi
	\ if getline(1) =~ '\<smil\>' |
	\   setf smil |
	\ else |
	\   setf mib |
	\ endif

au BufNewFile,BufRead *.smt,*.smith		setf smith

au BufNewFile,BufRead *.sno,*.spt		setf snobol4

au BufNewFile,BufRead *.mib,*.my		setf mib

au BufNewFile,BufRead *.hog,snort.conf,vision.conf	setf hog
au BufNewFile,BufRead *.rules			call s:FTRules()

let s:ft_rules_udev_rules_pattern = '^\s*\cudev_rules\s*=\s*"\([^"]\{-1,}\)/*".*'
func! s:FTRules()
  let path = expand('<amatch>:p')
  if path =~ '^/\(etc/udev/\%(rules\.d/\)\=.*\.rules\|lib/udev/\%(rules\.d/\)\=.*\.rules\)$'
    setf udevrules
    return
  endif
  if path =~ '^/etc/ufw/'
    setf conf  " Better than hog
    return
  endif
  if path =~ '^/\(etc\|usr/share\)/polkit-1/rules\.d'
    setf javascript
    return
  endif
  try
    let config_lines = readfile('/etc/udev/udev.conf')
  catch /^Vim\%((\a\+)\)\=:E484/
    setf hog
    return
  endtry
  let dir = expand('<amatch>:p:h')
  for line in config_lines
    if line =~ s:ft_rules_udev_rules_pattern
      let udev_rules = substitute(line, s:ft_rules_udev_rules_pattern, '\1', "")
      if dir == udev_rules
	setf udevrules
      endif
      break
    endif
  endfor
  setf hog
endfunc


au BufNewFile,BufRead *.spec			setf spec

au BufNewFile,BufRead *.speedup,*.spdata,*.spd	setf spup

au BufNewFile,BufRead *.ice			setf slice

au BufNewFile,BufRead *.sp,*.spice		setf spice

au BufNewFile,BufRead *.spy,*.spi		setf spyce

au BufNewFile,BufRead squid.conf		setf squid

au BufNewFile,BufRead *.tyb,*.typ,*.tyc,*.pkb,*.pks	setf sql

au BufNewFile,BufRead *.sql			call s:SQL()

func! s:SQL()
  if exists("g:filetype_sql")
    exe "setf " . g:filetype_sql
  else
    setf sql
  endif
endfunc

au BufNewFile,BufRead *.sqlj			setf sqlj

au BufNewFile,BufRead *.sqr,*.sqi		setf sqr

au BufNewFile,BufRead ssh_config,*/.ssh/config	setf sshconfig

au BufNewFile,BufRead sshd_config		setf sshdconfig

au BufNewFile,BufRead *.ado,*.do,*.imata,*.mata	setf stata
au BufNewFile,BufRead *.class
	\ if getline(1) !~ "^\xca\xfe\xba\xbe" | setf stata | endif

au BufNewFile,BufRead *.hlp,*.ihlp,*.smcl	setf smcl

au BufNewFile,BufRead *.stp			setf stp

au BufNewFile,BufRead *.sml			setf sml

au BufNewFile,BufRead *.cm			setf voscm

au BufNewFile,BufRead */etc/sysctl.conf,*/etc/sysctl.d/*.conf	setf sysctl

au BufNewFile,BufRead */systemd/*.{automount,mount,path,service,socket,swap,target,timer}	setf systemd

au BufNewFile,BufRead *.sdc			setf sdc

au BufNewFile,BufRead */etc/sudoers,sudoers.tmp	setf sudoers

au BufNewFile,BufRead *.svg			setf svg

func! s:FTperl()
  let dirname = expand("%:p:h:t")
  if expand("%:e") == 't' && (dirname == 't' || dirname == 'xt')
    setf perl
    return 1
  endif
  if getline(1)[0] == '#' && getline(1) =~ 'perl'
    setf perl
    return 1
  endif
  if search('^use\s\s*\k', 'nc', 30)
    setf perl
    return 1
  endif
  return 0
endfunc

au BufNewFile,BufRead *.t
	\ if !s:FTnroff() && !s:FTperl() | setf tads | endif

au BufNewFile,BufRead tags			setf tags

au BufNewFile,BufRead *.tak			setf tak

au BufRead,BufNewFile {pending,completed,undo}.data  setf taskdata
au BufRead,BufNewFile *.task			setf taskedit

au BufNewFile,BufRead *.tcl,*.tk,*.itcl,*.itk,*.jacl	setf tcl

au BufNewFile,BufRead *.tli			setf tli

au BufNewFile,BufRead *.slt			setf tsalt

au BufRead,BufNewFile *.ttl			setf teraterm

au BufNewFile,BufRead *.ti			setf terminfo

au BufNewFile,BufRead *.latex,*.sty,*.dtx,*.ltx,*.bbl	setf tex
au BufNewFile,BufRead *.tex			call s:FTtex()

func! s:FTtex()
  let firstline = getline(1)
  if firstline =~ '^%&\s*\a\+'
    let format = tolower(matchstr(firstline, '\a\+'))
    let format = substitute(format, 'pdf', '', '')
    if format == 'tex'
      let format = 'latex'
    elseif format == 'plaintex'
      let format = 'plain'
    endif
  elseif expand('%') =~ 'tex/context/.*/.*.tex'
    let format = 'context'
  else
    " Default value, may be changed later:
    let format = exists("g:tex_flavor") ? g:tex_flavor : 'plain'
    " Save position, go to the top of the file, find first non-comment line.
    let save_cursor = getpos('.')
    call cursor(1,1)
    let firstNC = search('^\s*[^[:space:]%]', 'c', 1000)
    if firstNC " Check the next thousand lines for a LaTeX or ConTeXt keyword.
      let lpat = 'documentclass\>\|usepackage\>\|begin{\|newcommand\>\|renewcommand\>'
      let cpat = 'start\a\+\|setup\a\+\|usemodule\|enablemode\|enableregime\|setvariables\|useencoding\|usesymbols\|stelle\a\+\|verwende\a\+\|stel\a\+\|gebruik\a\+\|usa\a\+\|imposta\a\+\|regle\a\+\|utilisemodule\>'
      let kwline = search('^\s*\\\%(' . lpat . '\)\|^\s*\\\(' . cpat . '\)',
			      \ 'cnp', firstNC + 1000)
      if kwline == 1	" lpat matched
	let format = 'latex'
      elseif kwline == 2	" cpat matched
	let format = 'context'
      endif		" If neither matched, keep default set above.
      " let lline = search('^\s*\\\%(' . lpat . '\)', 'cn', firstNC + 1000)
      " let cline = search('^\s*\\\%(' . cpat . '\)', 'cn', firstNC + 1000)
      " if cline > 0
      "   let format = 'context'
      " endif
      " if lline > 0 && (cline == 0 || cline > lline)
      "   let format = 'tex'
      " endif
    endif " firstNC
    call setpos('.', save_cursor)
  endif " firstline =~ '^%&\s*\a\+'

  " Translation from formats to file types.  TODO:  add AMSTeX, RevTex, others?
  if format == 'plain'
    setf plaintex
  elseif format == 'context'
    setf context
  else " probably LaTeX
    setf tex
  endif
  return
endfunc

au BufNewFile,BufRead *.mkii,*.mkiv,*.mkvi   setf context

au BufNewFile,BufRead *.texinfo,*.texi,*.txi	setf texinfo

au BufNewFile,BufRead texmf.cnf			setf texmf

au BufNewFile,BufRead .tidyrc,tidyrc		setf tidy

au BufNewFile,BufRead *.tf,.tfrc,tfrc		setf tf

au BufNewFile,BufRead {.,}tmux*.conf		setf tmux

au BufNewFile,BufReadPost *.tpp			setf tpp

au BufRead,BufNewFile *.treetop			setf treetop

au BufNewFile,BufRead trustees.conf		setf trustees

au BufNewFile,BufReadPost *.tssgm		setf tssgm

au BufNewFile,BufReadPost *.tssop		setf tssop

au BufNewFile,BufReadPost *.tsscl		setf tsscl

au BufNewFile,BufReadPost *.twig		setf twig

au BufNewFile,BufRead *.uit,*.uil		setf uil

au BufNewFile,BufRead */etc/udev/udev.conf	setf udevconf

au BufNewFile,BufRead */etc/udev/permissions.d/*.permissions setf udevperm
au BufNewFile,BufRead */etc/udev/cdsymlinks.conf	setf sh

au BufNewFile,BufRead *.uc			setf uc

au BufNewFile,BufRead */etc/updatedb.conf	setf updatedb

au BufNewFile,BufRead */usr/share/upstart/*.conf	       setf upstart
au BufNewFile,BufRead */usr/share/upstart/*.override	       setf upstart
au BufNewFile,BufRead */etc/init/*.conf,*/etc/init/*.override  setf upstart
au BufNewFile,BufRead */.init/*.conf,*/.init/*.override	       setf upstart
au BufNewFile,BufRead */.config/upstart/*.conf		       setf upstart
au BufNewFile,BufRead */.config/upstart/*.override	       setf upstart

au BufNewFile,BufRead *.vr,*.vri,*.vrh		setf vera

au BufNewFile,BufRead *.v			setf verilog

au BufNewFile,BufRead *.va,*.vams		setf verilogams

au BufNewFile,BufRead *.sv,*.svh		setf systemverilog

au BufNewFile,BufRead *.hdl,*.vhd,*.vhdl,*.vbe,*.vst  setf vhdl
au BufNewFile,BufRead *.vhdl_[0-9]*		call s:StarSetf('vhdl')

au BufNewFile,BufRead *.vim,*.vba,.exrc,_exrc	setf vim

au BufNewFile,BufRead .viminfo,_viminfo		setf viminfo

au BufRead,BufNewFile *.hw,*.module,*.pkg
	\ if getline(1) =~ '<?php' |
	\   setf php |
	\ else |
	\   setf virata |
	\ endif

au BufNewFile,BufRead *.frm			call s:FTVB("form")

au BufNewFile,BufRead *.sba			setf vb

au BufNewFile,BufRead vgrindefs			setf vgrindefs

au BufNewFile,BufRead *.wrl			setf vrml

au BufNewFile,BufRead *.vroom			setf vroom

au BufNewFile,BufRead *.wm			setf webmacro

au BufNewFile,BufRead .wgetrc,wgetrc		setf wget

au BufNewFile,BufRead *.wml			setf wml

au BufNewFile,BufRead *.wbt			setf winbatch

au BufNewFile,BufRead *.wsml			setf wsml

au BufNewFile,BufRead wvdial.conf,.wvdialrc	setf wvdial

au BufNewFile,BufRead .cvsrc			setf cvsrc

au BufNewFile,BufRead cvs\d\+			setf cvs

au BufNewFile,BufRead *.web
	\ if getline(1)[0].getline(2)[0].getline(3)[0].getline(4)[0].getline(5)[0] =~ "%" |
	\   setf web |
	\ else |
	\   setf winbatch |
	\ endif

au BufNewFile,BufRead *.ws[fc]			setf wsh

au BufNewFile,BufRead *.xhtml,*.xht		setf xhtml

au BufEnter *.xpm
	\ if getline(1) =~ "XPM2" |
	\   setf xpm2 |
	\ else |
	\   setf xpm |
	\ endif
au BufEnter *.xpm2				setf xpm2

au BufNewFile,BufRead XF86Config
	\ if getline(1) =~ '\<XConfigurator\>' |
	\   let b:xf86conf_xfree86_version = 3 |
	\ endif |
	\ setf xf86conf
au BufNewFile,BufRead */xorg.conf.d/*.conf
	\ let b:xf86conf_xfree86_version = 4 |
	\ setf xf86conf

au BufNewFile,BufRead xorg.conf,xorg.conf-4	let b:xf86conf_xfree86_version = 4 | setf xf86conf

au BufNewFile,BufRead */etc/xinetd.conf		setf xinetd

au BufNewFile,BufRead *.xs			setf xs

au BufNewFile,BufRead .Xdefaults,.Xpdefaults,.Xresources,xdm-config,*.ad setf xdefaults

au BufNewFile,BufRead *.msc,*.msf		setf xmath
au BufNewFile,BufRead *.ms
	\ if !s:FTnroff() | setf xmath | endif

au BufNewFile,BufRead *.xml			call s:FTxml()

func! s:FTxml()
  let n = 1
  while n < 100 && n < line("$")
    let line = getline(n)
    " DocBook 4 or DocBook 5.
    let is_docbook4 = line =~ '<!DOCTYPE.*DocBook'
    let is_docbook5 = line =~ ' xmlns="http://docbook.org/ns/docbook"'
    if is_docbook4 || is_docbook5
      let b:docbk_type = "xml"
      if is_docbook5
	let b:docbk_ver = 5
      else
	let b:docbk_ver = 4
      endif
      setf docbk
      return
    endif
    if line =~ 'xmlns:xbl="http://www.mozilla.org/xbl"'
      setf xbl
      return
    endif
    let n += 1
  endwhile
  setf xml
endfunc

au BufNewFile,BufRead *.xmi			setf xml

au BufNewFile,BufRead *.csproj,*.csproj.user	setf xml

au BufNewFile,BufRead *.ts,*.ui			setf xml

au BufNewFile,BufRead *.tpm			setf xml

au BufNewFile,BufRead */etc/xdg/menus/*.menu	setf xml

au BufNewFile,BufRead fglrxrc			setf xml

au BufNewFile,BufRead *.xlf			setf xml
au BufNewFile,BufRead *.xliff			setf xml

au BufNewFile,BufRead *.xul			setf xml

au BufNewFile,BufRead *Xmodmap			setf xmodmap

au BufNewFile,BufRead *.xq,*.xql,*.xqm,*.xquery,*.xqy	setf xquery

au BufNewFile,BufRead *.xsd			setf xsd

au BufNewFile,BufRead *.xsl,*.xslt		setf xslt

au BufNewFile,BufRead *.yy,*.yxx,*.y++		setf yacc

au BufNewFile,BufRead *.y			call s:FTy()

func! s:FTy()
  let n = 1
  while n < 100 && n < line("$")
    let line = getline(n)
    if line =~ '^\s*%'
      setf yacc
      return
    endif
    if getline(n) =~ '^\s*\(#\|class\>\)' && getline(n) !~ '^\s*#\s*include'
      setf racc
      return
    endif
    let n = n + 1
  endwhile
  setf yacc
endfunc


au BufNewFile,BufRead *.yaml,*.yml		setf yaml

au BufNewFile,BufRead */etc/yum.conf		setf dosini

au BufNewFile,BufRead *.zu			setf zimbu
au BufNewFile,BufRead *.zut			setf zimbutempl

au BufNewFile,BufRead *.dtml,*.pt,*.cpt		call s:FThtml()
au BufNewFile,BufRead *.zsql			call s:SQL()

au BufNewFile,BufRead *.z8a			setf z8a

augroup END


if exists("myfiletypefile") && filereadable(expand(myfiletypefile))
  execute "source " . myfiletypefile
endif


augroup filetypedetect
au BufNewFile,BufRead *
	\ if !did_filetype() && expand("<amatch>") !~ g:ft_ignore_pat
	\ | runtime! scripts.vim | endif
au StdinReadPost * if !did_filetype() | runtime! scripts.vim | endif



au BufNewFile,BufRead access.conf*,apache.conf*,apache2.conf*,httpd.conf*,srm.conf*	call s:StarSetf('apache')
au BufNewFile,BufRead */etc/apache2/*.conf*,*/etc/httpd/conf.*/*,*/etc/httpd/mods-*/*,*/etc/httpd/sites-*/*,*/etc/httpd/conf.d/*.conf*,auth_mysql.conf*,auth_pgsql.conf*,ssl.conf*,perl.conf*,php.conf*,python.conf*,squirrelmail.conf*		call s:StarSetf('apache')

au BufNewFile,BufRead *asterisk/*.conf*		call s:StarSetf('asterisk')
au BufNewFile,BufRead *asterisk*/*voicemail.conf* call s:StarSetf('asteriskvm')

au BufNewFile,BufRead bzr_log.*			setf bzr

if !has("fname_case")
  au BufNewFile,BufRead BUILD			setf bzl
endif

au BufNewFile,BufRead */named/db.*,*/bind/db.*	call s:StarSetf('bindzone')

au BufNewFile,BufRead */.calendar/*,
	\*/share/calendar/*/calendar.*,*/share/calendar/calendar.*
	\					call s:StarSetf('calendar')

au BufNewFile,BufRead [cC]hange[lL]og*
	\ if getline(1) =~ '; urgency='
	\|  call s:StarSetf('debchangelog')
	\|else
	\|  call s:StarSetf('changelog')
	\|endif

au BufNewFile,BufRead crontab,crontab.*,*/etc/cron.d/*		call s:StarSetf('crontab')

au BufNewFile,BufRead */etc/dnsmasq.d/*		call s:StarSetf('dnsmasq')

au BufNewFile,BufRead drac.*			call s:StarSetf('dracula')

au BufNewFile,BufRead */.fvwm/*			call s:StarSetf('fvwm')
au BufNewFile,BufRead *fvwmrc*,*fvwm95*.hook
	\ let b:fvwm_version = 1 | call s:StarSetf('fvwm')
au BufNewFile,BufRead *fvwm2rc*
	\ if expand("<afile>:e") == "m4"
	\|  call s:StarSetf('fvwm2m4')
	\|else
	\|  let b:fvwm_version = 2 | call s:StarSetf('fvwm')
	\|endif

au BufNewFile,BufRead */tmp/lltmp*		call s:StarSetf('gedcom')

au BufNewFile,BufRead .gtkrc*,gtkrc*		call s:StarSetf('gtkrc')

au BufNewFile,BufRead Prl*.*,JAM*.*		call s:StarSetf('jam')

au! BufNewFile,BufRead *jarg*
	\ if getline(1).getline(2).getline(3).getline(4).getline(5) =~? 'THIS IS THE JARGON FILE'
	\|  call s:StarSetf('jargon')
	\|endif

au BufNewFile,BufRead Kconfig.*			call s:StarSetf('kconfig')

au BufNewFile,BufRead lilo.conf*		call s:StarSetf('lilo')

au BufNewFile,BufRead */etc/logcheck/*.d*/*	call s:StarSetf('logcheck')

au BufNewFile,BufRead [mM]akefile*		call s:StarSetf('make')

au BufNewFile,BufRead [rR]akefile*		call s:StarSetf('ruby')

au BufNewFile,BufRead mutt[[:alnum:]._-]\\\{6\}	setf mail

au BufNewFile,BufRead reportbug-*		call s:StarSetf('mail')

au BufNewFile,BufRead */etc/modutils/*
	\ if executable(expand("<afile>")) != 1
	\|  call s:StarSetf('modconf')
	\|endif
au BufNewFile,BufRead */etc/modprobe.*		call s:StarSetf('modconf')

au BufNewFile,BufRead .mutt{ng,}rc*,*/.mutt{ng,}/mutt{ng,}rc*	call s:StarSetf('muttrc')
au BufNewFile,BufRead mutt{ng,}rc*,Mutt{ng,}rc*		call s:StarSetf('muttrc')

au BufNewFile,BufRead tmac.*			call s:StarSetf('nroff')

au BufNewFile,BufRead /etc/hostname.*		call s:StarSetf('config')

au BufNewFile,BufRead */etc/pam.d/*		call s:StarSetf('pamconf')

au BufNewFile,BufRead *printcap*
	\ if !did_filetype()
	\|  let b:ptcap_type = "print" | call s:StarSetf('ptcap')
	\|endif
au BufNewFile,BufRead *termcap*
	\ if !did_filetype()
	\|  let b:ptcap_type = "term" | call s:StarSetf('ptcap')
	\|endif

au BufRead,BufNewFile *.rdf			call s:Redif()
func! s:Redif()
  let lnum = 1
  while lnum <= 5 && lnum < line('$')
    if getline(lnum) =~ "^\ctemplate-type:"
      setf redif
      return
    endif
    let lnum = lnum + 1
  endwhile
endfunc

au BufNewFile,BufRead .reminders*		call s:StarSetf('remind')

au BufNewFile,BufRead *vimrc*			call s:StarSetf('vim')

au BufNewFile,BufRead svn-commit*.tmp		setf svn

au BufNewFile,BufRead Xresources*,*/app-defaults/*,*/Xresources/* call s:StarSetf('xdefaults')

au BufNewFile,BufRead XF86Config-4*
	\ let b:xf86conf_xfree86_version = 4 | call s:StarSetf('xf86conf')
au BufNewFile,BufRead XF86Config*
	\ if getline(1) =~ '\<XConfigurator\>'
	\|  let b:xf86conf_xfree86_version = 3
	\|endif
	\|call s:StarSetf('xf86conf')

au BufNewFile,BufRead *xmodmap*			call s:StarSetf('xmodmap')

au BufNewFile,BufRead */etc/xinetd.d/*		call s:StarSetf('xinetd')

au BufNewFile,BufRead */etc/yum.repos.d/*	call s:StarSetf('dosini')

au BufNewFile,BufRead zsh*,zlog*		call s:StarSetf('zsh')


au BufNewFile,BufRead *.text,README		setf text

au BufNewFile,BufRead *.txt	
	\  if getline('$') !~ 'vim:.*ft=help'
	\|   setf text
	\| endif


runtime! ftdetect/*.vim

augroup END

au filetypedetect BufNewFile,BufRead,StdinReadPost *
	\ if !did_filetype() && expand("<amatch>") !~ g:ft_ignore_pat
	\    && (getline(1) =~ '^#' || getline(2) =~ '^#' || getline(3) =~ '^#'
	\	|| getline(4) =~ '^#' || getline(5) =~ '^#') |
	\   setf FALLBACK conf |
	\ endif


if has("menu") && has("gui_running")
      \ && !exists("did_install_syntax_menu") && &guioptions !~# "M"
  source <sfile>:p:h/menu.vim
endif

func! TestFiletypeFuncs(testlist)
  let output = ''
  for f in a:testlist
    try
      exe f
    catch
      let output = output . "\n" . f . ": " . v:exception
    endtry
  endfor
  return output
endfunc

let &cpo = s:cpo_save
unlet s:cpo_save
